# -*- coding: utf-8 -*-
# from django.utils.translation import gettext_lazy as _
from django.db import models


# class SourceCode(models.Model):
#     name = models.CharField(_("Name"), max_length=100)
#     source_code = models.TextField(_("Source code"))
#     source_code2 = models.TextField(_("Source code2"))

#     class Meta:
#         verbose_name = _("Source code")
#         verbose_name_plural = _("Source codes")

#     def __str__(self):
#         return self.name


# class SourceItem(models.Model):
#     source_code = models.ForeignKey(SourceCode, verbose_name=_('Source code'),
#         on_delete=models.CASCADE, related_name='source_code_items')
#     source1 = models.TextField(_("Source 1"))
#     source2 = models.TextField(_("Source 2"))

#     class Meta:
#         verbose_name = _("Source item")
#         verbose_name_plural = _("Source items")



# -*- coding: utf-8 -*-
from django.forms import Media
from django.contrib import admin

from . import models
from . import forms


class MonacoAdminMixin:
    """Use this mixin with a ModelAdmin subclass that is using the
    widget `djwidgetdefinitions.widgets.MonacoEditorWidget`.
    """
    def render_change_form(self, request, context, add, change, form_url, obj = None):
        monaco_js = [
            'https://unpkg.com/monaco-editor@0.40.0/min/vs/loader.js',
            'https://unpkg.com/emmet-monaco-es/dist/emmet-monaco.min.js',
            'djmonaco/monaco-editor.js',
        ]
        js_assets = list(context['media']._js)
        js_assets = [asset for asset in js_assets if asset not in monaco_js]
        js_assets.extend(monaco_js)
        media = Media(css=context['media']._css, js=js_assets)
        context['media'] = media
        return super().render_change_form(request, context, add=add, change=change, form_url=form_url, obj=obj)


# class SourceItemInline(admin.StackedInline):
#     model = models.SourceItem
#     fields = ('source1', 'source2')
#     form = forms.SourceItemForm
#     extra = 0


# @admin.register(models.SourceCode)
# class SourceCodeAdmin(MonacoAdminMixin, admin.ModelAdmin):
#     list_display = ('name',)
#     form = forms.SourceCodeForm
#     inlines = [SourceItemInline]



from django import forms

from . import widgets
from . import models


# class SourceCodeForm(forms.ModelForm):
#     class Meta:
#         model = models.SourceCode
#         fields = ('name', 'source_code', 'source_code2')
#         widgets = {
#             "source_code": widgets.MonacoEditorWidget(
#                 attrs={"data-language": "html"}
#             ),
#             "source_code2": widgets.MonacoEditorWidget(
#                 attrs={"data-language": "javascript"}
#             ),
#         }


# class SourceItemForm(forms.ModelForm):
#     class Meta:
#         model = models.SourceItem
#         fields = ('source1', 'source2')
#         widgets = {
#             "source1": widgets.MonacoEditorWidget(
#                 attrs={"data-language": "html"}
#             ),
#             "source2": widgets.MonacoEditorWidget(
#                 attrs={"data-language": "javascript"}
#             ),
#         }



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_dj-monaco
------------

Tests for `dj-monaco` models module.
"""

from django.test import TestCase

from djmonaco import models


class TestDjmonaco(TestCase):

    def setUp(self):
        pass

    def test_something(self):
        pass

    def tearDown(self):
        pass
